PyHydro
###################
Python package applied to the planning of the operation of energy systems in the medium term horizon. This package also has classes applied to rain-to-flow

USAGE
###################

from PyHydro.<class> import <class>

EXAMPLE
###################

from PyHydro.pmo import pmo

q = pmo('/')